@@ -14,6 +14,8 @@ use crate::node::{
     Result,
 };
 use sn_interface::elder_count;
+#[cfg(feature = "back-pressure")]
+use sn_interface::messaging::DstLocation;
 use sn_interface::messaging::{system::SystemMsg, AuthKind, WireMsg};
 use sn_interface::types::{log_markers::LogMarker, Peer};
 
@@ -24,6 +26,8 @@ use tokio::{sync::watch, time};
 use tracing::Instrument;
 
 const PROBE_INTERVAL: Duration = Duration::from_secs(30);
+#[cfg(feature = "back-pressure")]
+const BACKPRESSURE_INTERVAL: Duration = Duration::from_secs(60);
 const LINK_CLEANUP_INTERVAL: Duration = Duration::from_secs(120);
 const DYSFUNCTION_CHECK_INTERVAL: Duration = Duration::from_secs(60);
 
@@ -216,6 +220,80 @@ impl Dispatcher {
         });
     }
 
+    #[cfg(feature = "back-pressure")]
+    /// Periodically send back-pressure reports to our section.
+    ///
+    /// We do not send reports outside of the section as most messages will come from within our section
+    /// (and there's no easy way to determine what incoming mesages are spam, or joining nodes etc)
+    /// Worst case is after a split, nodes sending messaging from a sibling section to update us may not
+    /// know about our load just now. Though that would only be AE messages... and if backpressure is working we should
+    /// not be overloaded...
+    pub(super) async fn report_backpressure_to_our_section_periodically(self: Arc<Self>) {
+        info!("Firing off backpressure reports");
+        let _handle = tokio::spawn(async move {
+            let dispatcher = self.clone();
+            let mut interval = tokio::time::interval(BACKPRESSURE_INTERVAL);
+            interval.set_missed_tick_behavior(MissedTickBehavior::Skip);
+            let _ = interval.tick().await;
+
+            loop {
+                let _ = interval.tick().await;
+
+                let members = dispatcher.node.network_knowledge().section_members().await;
+                let section_pk = dispatcher.node.network_knowledge().section_key().await;
+
+                if let Some(load_report) = dispatcher.node.comm.tolerated_msgs_per_s().await {
+                    trace!("New BackPressure report to disseminate: {:?}", load_report);
+
+                    // TODO: use comms to send report to anyone connected? (can we ID end users there?)
+                    for member in members {
+                        let our_name = dispatcher.node.info.read().await.name();
+                        let peer = member.peer();
+
+                        if peer.name() == our_name {
+                            continue;
+                        }
+
+                        let wire_msg = match WireMsg::single_src(
+                            &*dispatcher.node.info.read().await,
+                            DstLocation::Node {
+                                name: peer.name(),
+                                section_pk,
+                            },
+                            SystemMsg::BackPressure(load_report),
+                            section_pk,
+                        ) {
+                            Ok(msg) => msg,
+                            Err(e) => {
+                                error!(
+                                    "Error forming backpressure message to section member {:?}",
+                                    e
+                                );
+                                continue;
+                            }
+                        };
+
+                        let cmd = Cmd::SendMsg {
+                            wire_msg,
+                            recipients: vec![*peer],
+                        };
+
+                        if let Err(e) = dispatcher
+                            .clone()
+                            .enqueue_and_handle_next_cmd_and_offshoots(cmd, None)
+                            .await
+                        {
+                            error!(
+                                "Error sending backpressure report to section member {:?}: {:?}",
+                                peer, e
+                            );
+                        }
+                    }
+                }
+            }
+        });
+    }
+
     pub(super) async fn write_prefixmap_to_disk(self: Arc<Self>) {
         info!("Writing our PrefixMap to disk");
         self.clone().node.write_prefix_map().await
